@@ -21,6 +21,7 @@ import os
 import tempfile
 import copy
 import click
+from . import module_tools
 from . import tools
 from .tools import __replace_all_envs_in_str
 from .tools import __running_as_root_or_sudo
@@ -395,7 +396,7 @@ def _execute_after_compose(config, yml):
     execute local __oncompose.py scripts
     """
     from .myconfigparser import MyConfigParser
-    from .module_tools import Modules
+    from .module_tools import Modules, Module
 
     settings = MyConfigParser(config.files["settings"])
     modules = Modules()
@@ -417,6 +418,8 @@ def _execute_after_compose(config, yml):
                 dict(
                     Modules=modules,
                     tools=tools,
+                    module_tools=module_tools,
+                    Module=Module,
                 ),
             )
 
